@@ -1,4 +1,5 @@
-import inspect, itertools, os, glob
+import functools, inspect, itertools, os, glob
+from collections import abc
 
 from django.apps import apps
 from django.db import models
@@ -171,11 +172,13 @@ def find_models_module(current=None):
 
     paths = []
     while is_subdir(root, current):
-        for path in glob.glob('**/models.py', recursive=True, root_dir=current):
-            p = os.path.join(current, path)
-            if p in paths:
+        globs = f'{current}/**/models.py'
+        print(globs)
+        for path in glob.glob(globs, recursive=True):
+            path = os.path.realpath(path)
+            if path in paths:
                 continue
-            paths.append(p)
+            paths.append(path)
         current = os.path.dirname(current)
 
     if not paths:
@@ -199,4 +202,36 @@ def select_kwargs(callable, *args, allowed_params:list=None, **kwargs):
         key: value for key, value in kwargs.items()
         if key in allowed_params
     }
-    return callable(*args, **kwargs)
\ No newline at end of file
+    return callable(*args, **kwargs)
+
+
+def is_many_type(value) -> bool:
+    if isinstance(value, abc.Iterable):
+        if isinstance(value, abc.Mapping):
+            return False
+        elif isinstance(value, abc.Sequence):
+            if isinstance(value, (str, bytes)):
+                return False
+        return True
+    return False
+    
+
+
+def singulize(value) -> abc.Generator:
+    if not is_many_type(value):
+        if value is not None:
+            yield value
+    else:
+        for row in value:
+            yield from singulize(row)
+
+
+def pluralize(value) -> list:
+    pluralized = []
+    if not is_many_type(value):
+        if value is not None:
+            pluralized.append(value)
+    else:
+        for row in value:
+            pluralized += pluralize(row)
+    return pluralized
\ No newline at end of file
