@@ -2,7 +2,7 @@ from pipe2db import pipe, setupdb
 from django.apps import apps
 
 
-setupdb()
+setupdb(default_db_name='pipe2db_test.sqlite3')
 
 
 author1 = {
@@ -28,34 +28,26 @@ author3 = {
 }
 
 
-
-# create
-@pipe({
+context_author = {
     'model': 'db.Author',
     'unique_key': 'email',
-})
+}
+
+# create
+@pipe(context_author)
 def insert(Author):
     qs = Author.objects.values_list()
     for row in qs:
         print(row)
     
-    yield author1
-    yield author2
-    yield author3
-
-
+    yield [author1, author2, author3]
 
+context_author['method'] = 'update'
 # create or update
-@pipe({
-    'model': 'db.Author',
-    'unique_key': 'email',
-    'method': 'update'
-})
+@pipe(context_author)
 def insert_and_update():
-    author1['first_name'] = 'updated'
-    yield author2
-    yield author3
-    yield author1
+    author1['first_name'] = 'updated1'
+    yield from [author1, author2, author3]
 
 
 
